@@ -1,6 +1,6 @@
 package App::Greple::xlate::gpt4;
 
-our $VERSION = "0.9910";
+our $VERSION = "0.9911";
 
 use v5.14;
 use warnings;
@@ -27,11 +27,15 @@ my %param = (
 	      prompt => <<END
 Translate the following text into %s, preserving the line structure.
 For each input line, output only the corresponding translated line in the same line position.
-Leave blank lines and any XML-style tags (e.g., <m id=1 />, <tag>, </tag>) unchanged and do not translate them.
+If the input consists of only one line, ensure that the output is also a single line.
+If your translation would normally result in multiple lines, combine them into one line so that the number of output lines always matches the input.
+Leave blank lines and any XML-style marker tags (e.g., <m id=1 />) unchanged and do not translate them.
 Do not output the original (pre-translation) text under any circumstances.
 The number and order of output lines must always match the input exactly: output line n must correspond to input line n.
 Output only the translated lines or unchanged tags/blank lines.
-**Before finishing, carefully check that there are absolutely no omissions or duplicate content of any kind in your output.**
+**Make sure that every XML-style numbered tag present in the input also appears in the output.**
+**Do not leave any unnecessary spaces or tabs at the end of any line in your output.**
+**Before finishing, carefully check that there are absolutely no omissions, duplicate content, or trailing spaces of any kind in your output.**
 END
 	  },
 );
